function handles = detectInterf(handles)

wait = waitbar(0, 'Detecting interference...');

set(handles.text_out_lat, 'String', 'Lat: ')
set(handles.text_out_lon, 'String', 'Lon: ')
set(handles.text_out_err, 'String', 'Error: ')

airspeed = str2double(get(handles.edit_airspeed, 'String'));
timeArray = cumsum(timeUtils.getArrayTime( ...
            handles.waypoints, airspeed));
time = 0:0.01:timeArray(end);

% Select start and end time of detection
maxPower = -155;
vals = handles.agc > maxPower;
times = time(vals);
%interf_start = str2double(get(handles.edit_start_jam, 'String'));
interf_start = times(1);
%interf_end = str2double(get(handles.edit_end_jam, 'String'));
interf_end = times(end);

% Select three points inside interference and get power
interfIdx = time >= interf_start & time <= interf_end;
interfSamples = handles.agc(interfIdx);
interfTime = time(interfIdx);
timeBetweenSamples = 1000;
if timeBetweenSamples > floor((length(interfTime)/2)) -1
    timeBetweenSamples = floor((length(interfTime)/2)) -1;
end

waitbar(0.4, wait, 'Locating interference...')
lats = []; lons = [];
i = 1;
while (i + 2 * timeBetweenSamples) <= length(interfTime)
%for i = 1:timeBetweenSamples:(floor((length(interfTime)/2))-1)
    interfPower = [interfSamples(i) ...
        interfSamples(i + timeBetweenSamples) ...
        interfSamples(i + 2 * timeBetweenSamples)];
    interfSeconds =  [interfTime(i) ...
        interfTime(i + timeBetweenSamples) ...
        interfTime(i + 2 * timeBetweenSamples)];
    f = @(d) getInterfDistance(d,interfPower);
    d0 = [1e3,1e3,1e3];
    d = fsolve(f,d0);


    pos1 = positionUtils.getPositionAtS(handles.waypoints, ...
             str2double(get(handles.edit_airspeed, 'String')), ...
             interfSeconds(1));
    pos2 = positionUtils.getPositionAtS(handles.waypoints, ...
             str2double(get(handles.edit_airspeed, 'String')), ...
             interfSeconds(2));
    pos3 = positionUtils.getPositionAtS(handles.waypoints, ...
             str2double(get(handles.edit_airspeed, 'String')), ...
             interfSeconds(3));

   posInS = [pos1; pos2; pos3];

    [latsAux,lonsAux] = scxsc(posInS(:,1),posInS(:,2), ...
        km2deg(d'/1000), [posInS(2:end,1);posInS(1,1)], ... 
        [posInS(2:end,2);posInS(1,2)], ...
        km2deg([d(2:end) d(1)]'/1000));
        

%     [latsAux, lonsAux] = trilateration(pos1(1),pos1(2),pos1(3)/1000, ...
%         d(1)/1000, pos2(1),pos2(2),pos2(3)/1000, d(2)/1000, ...
%         pos3(1),pos3(2),pos3(3)/1000, d(3)/1000);

    lats = [lats; latsAux];
    lons = [lons; lonsAux];
    
    i = i + 1;
end

lats = lats(all(~isnan(lats),2),:);
lons = lons(all(~isnan(lons),2),:);

[~,latOrLon] = max([mean(abs(diff(lats')')), ...
    mean(abs(diff(lons')'))]);

if latOrLon == 1
    [lats,latsIdx] = sort(lats,2);
    for i=1:size(lons,1)
        aux = lons(i,:);
        lons(i,:) = aux(latsIdx(i,:));
        
    end
elseif latOrLon == 2
    [lons,lonsIdx] = sort(lons,2);
    for i=1:size(lats,1)
        aux = lats(i,:);
        lats(i,:) = aux(lonsIdx(i,:));
        
    end
    
end


[~,idxClosest] = min(sum(abs(diff(lons))) + ...
     sum(abs(diff(lats))));
 


% Plot solution and show coordinates
waitbar(0.9, wait, 'Ploting solution...')
handles.isAnalysed = true;
handles.lats = lats(:,idxClosest);
handles.lons = lons(:,idxClosest);
% handles.lats = lats;
% handles.lons = lons;
handles.interf_start = interf_start;
handles.interf_end = interf_end;
set(handles.text_out_lat, 'String', ['Lat: ' num2str(mean(handles.lats))])
set(handles.text_out_lon, 'String', ['Lon: ' num2str(mean(handles.lons))])


set(handles.text_out_err, 'String', ['Error:' ...
    num2str(positionUtils.haversine(mean(handles.lats), ...
    mean(handles.lons), str2double(get(handles.edit_lat, 'String')), ...
    str2double(get(handles.edit_lon, 'String')))) ' m'])

handles = plotMap(handles);
handles = plotAGC(handles);
close(wait)