%Get AGC values
function handles = getAGC(handles)
airspeed = str2double(get(handles.edit_airspeed, 'String'));
timeArray = cumsum(timeUtils. getArrayTime( ...
            handles.waypoints, airspeed));
time = 0:0.01:timeArray(end);
txPower = 1e-8;

%Set tx/rx and compute power
tx = txsite('Name', 'Transmitter', ...
    'Latitude', handles.waypoints(1,1), ...
    'Longitude', handles.waypoints(1,2), ...
    'AntennaHeight', handles.waypoints(1,3)+4000, ...
    'TransmitterPower', txPower);
rx = rxsite('Name', 'Receiver', ...
    'Latitude', handles.waypoints(1,1), ...
    'Longitude', handles.waypoints(1,2), ...
    'AntennaHeight', handles.waypoints(1,3), ...
    'ReceiverSensitivity', -174);
pm = propagationModel('freespace');
noise = 10*log(awgn(ones(1,length(time)),33));
rxTxPower = sigstrength(rx,tx, pm) * ones(1,length(time)) + noise;

%Initialize jammer
jammerPower = 1e-8;
jammer_lat = str2double(get(handles.edit_lat, 'String'));
jammer_lon = str2double(get(handles.edit_lon, 'String'));
jammer_alt = str2double(get(handles.edit_alt, 'String'));
jammer_pos = [jammer_lat jammer_lon jammer_alt];
jammer = txsite('Name', 'Transmitter', ...
    'Latitude', jammer_pos(1), ...
    'Longitude', jammer_pos(2), ...
    'AntennaHeight', jammer_pos(3), ...
    'TransmitterPower', jammerPower);
jammer_start = str2double(get(handles.edit_start_jam, 'String'));
jammer_end = str2double(get(handles.edit_end_jam, 'String'));

ss = zeros(1, length(time));
posByTime = zeros(length(time), 3);
for i = 1:length(time)
    posinS = positionUtils.getPositionAtS(handles.waypoints, ...
        airspeed, time(i));
    posByTime(i,:) = posinS;
    rx.Latitude = posinS(1); 
    rx.Longitude = posinS(2);
    rx.AntennaHeight = posinS(3);
    if time(i) >= jammer_start && time(i) < jammer_end
       s = max([sigstrength(rx,jammer, pm)+noise(i) rxTxPower(i)]);
    else
        s = rxTxPower(i);
    end
    ss(i) = s;
end
handles.agc = ss;
handles.posByTime = posByTime;