% Get errors statistics 
function handles = getErrorStatistics(handles)

% Compare real jammer position to compùted positions

jammer_lat = str2double(get(handles.edit_lat, 'String'));
jammer_lon = str2double(get(handles.edit_lon, 'String'));
jammer_alt = str2double(get(handles.edit_alt, 'String'));

[eH, ~] = positionUtils.getError2ref( [jammer_lat jammer_lon jammer_alt], ...
    [handles.lats'; handles.lons'; ones(1,length(handles.lats))]');

% Compute mean and standard deviation
mu = positionUtils.haversine(mean(handles.lats), ...
    mean(handles.lons), jammer_lat, jammer_lon);
sigma = std(eH);

% Plot statistics
figure('Name', 'Error Statistics', 'NumberTitle', 'off')
subplot(4,1,[1 2 3])
histogram(eH, 'Normalization', 'probability');
xline(mu, 'Color', 'g', 'LineWidth', 2);
xline(mu - sigma, 'Color', 'r', 'LineWidth', 2, 'LineStyle', '--');
xline(mu + sigma, 'Color', 'r', 'LineWidth', 2, 'LineStyle', '--');
xlabel('Error (m)');
ylabel('Frequency (%)');
title('Distance Error');
legend('', 'Mean error', 'Standard deviation');
tableAxes = subplot(4,1,4);
set(tableAxes,'visible','off')
table = uitable('Data', {[num2str(jammer_lat) ...
    ', ' num2str(jammer_lon)], [num2str(mean(handles.lats)) ...
    ', ' num2str(mean(handles.lons))], mu, sigma},...
    'ColumnName', {'Real Position', 'Computed Position', ...
    'Mean Error', 'Standard Deviation'}, ...
    'RowName', []);
table.Units = tableAxes.Units;
table.Position = tableAxes.Position;