classdef positionUtils
    methods(Static)
        
        
        % Get position at specific second
        function pos = getPositionAtS(waypoints, speed, s)
            time = cumsum(timeUtils.getArrayTime(waypoints, speed));

           idx = sort([time' s]) == s;
           speeds = speedUtils.getArraySpeed(waypoints,speed);
           p0 = waypoints(idx,:);
           v0 = speeds(idx,:);
           if find(idx) == 1
               t0 = 0;
           else
               t0 = time(find(idx)-1);
           end
           pos = p0 + v0 * (s - t0);
               
               
        end
        
        % Get error between reference position and array of positions
        function [errorH, errorV] = getError2ref(ref,positions)
            R = 6372800;
            dlat = deg2rad(ref(1)-positions(:,1));
            dlon = deg2rad(ref(2)-positions(:,2));
            lat1 = deg2rad(ref(1));
            lat2 = deg2rad(positions(:,1));
            a = (sin(dlat./2)).^2 + cos(lat1) .* cos(lat2) .* (sin(dlon./2)).^2;
            c = 2 .* asin(sqrt(a));
            errorH = R * c;
            errorV = ref(3) - positions(:,3);

        end
        
        % Get distance between coordinates in array
        function distance = haversine3Darray(waypoints)
            R = 6372800;
            dlat = deg2rad(diff(waypoints(:,1)));
            dlon = deg2rad(diff(waypoints(:,2)));
            lat1 = deg2rad(waypoints(1:end-1,1));
            lat2 = deg2rad(waypoints(2:end,1));
            a = (sin(dlat./2)).^2 + cos(lat1) .* cos(lat2) .* (sin(dlon./2)).^2;
            c = 2 .* asin(sqrt(a));
            dhor = R * c;
            distance = sqrt(dhor.^2 + (diff(waypoints(:,3))).^2);
        end
        
        % Get distance between coordinates in array
        function distance = haversine2DArray(waypoints)
            R = 6372800;
            dlat = deg2rad(diff(waypoints(:,1)));
            dlon = deg2rad(diff(waypoints(:,2)));
            lat1 = deg2rad(waypoints(1:end-1,1));
            lat2 = deg2rad(waypoints(2:end,1));
            a = (sin(dlat./2)).^2 + cos(lat1) .* cos(lat2) .* (sin(dlon./2)).^2;
            c = 2 .* asin(sqrt(a));
            distance = R * c;
        end
        
        % Get distance between two coordinates using Haversine formula
        function distance = haversine(lat1,lon1,lat2,lon2)
            R = 6372800;
            dlat = deg2rad(lat2-lat1);
            dlon = deg2rad(lon2-lon1);
            lat1 = deg2rad(lat1);
            lat2 = deg2rad(lat2);
            a = (sin(dlat./2)).^2 + cos(lat1) .* cos(lat2) .* (sin(dlon./2)).^2;
            c = 2 .* asin(sqrt(a));
            distance = R * c;
        end
        
        % Get distance between two coordinates in 3D using Haversine formula
        function distance = haversine3D(point1,point2)
            dhor = positionUtils.haversine(point1(1),point1(2), ...
                point2(1),point2(2));
            distance = sqrt(dhor^2 + ...
                (point1(3) - point2(3))^2);
        end
        
        % Get distance between waypoints
        function distance = getWaypointsDistance(waypoints)
            distance = sqrt(sum(diff(waypoints).^2,2));
        end
        
        % Get distance between 3D points
        function distance = getDistance(point1, point2)
            distance = sqrt(sum((point2 - point1).^2));
        end
        
        % Convert degrees to radians
        function rad = deg2rad(degree) 
            rad = degree .* pi / 180;
        end
        
        % Convert radians to degrees
        function deg = rad2deg(radians) 
            deg =  radians .* 180 / pi;
        end 
        
    end
end
    